entropy.empirical estimates the Shannon entropy H
of the random variable Y from the corresponding observed counts y
by plug-in of the empirical frequencies.
freqs.empirical computes the empirical frequencies from counts y.
entropy.empirical returns an estimate of the Shannon entropy.
freqs.empirical returns the underlying frequencies.
Details
The empirical entropy estimator is a plug-in estimator:
in the definition of the Shannon entropy the
bin probabilities are replaced by the respective empirical frequencies.
The empirical entropy estimator is the maximum likelihood estimator.
If there are many zero counts and the sample size is small
it is very inefficient and also strongly biased.